package java.nio.channels;

import java.util.concurrent.Future;
import java.net.SocketOption;
import java.net.SocketAddress;
import java.io.IOException;
import java.nio.channels.spi.AsynchronousChannelProvider;

public abstract class AsynchronousServerSocketChannel implements AsynchronousChannel, NetworkChannel
{
    private final AsynchronousChannelProvider provider;
    
    protected AsynchronousServerSocketChannel(AsynchronousChannelProvider provider) {
        this.provider = provider;
    }
    
    public final AsynchronousChannelProvider provider() {
        return this.provider;
    }
    
    public static AsynchronousServerSocketChannel open(AsynchronousChannelGroup asynchronousChannelGroup) throws IOException {
        return ((asynchronousChannelGroup == null) ? AsynchronousChannelProvider.provider() : asynchronousChannelGroup.provider()).openAsynchronousServerSocketChannel(asynchronousChannelGroup);
    }
    
    public static AsynchronousServerSocketChannel open() throws IOException {
        return open(null);
    }
    
    @Override
    public final AsynchronousServerSocketChannel bind(SocketAddress socketAddress) throws IOException {
        return this.bind(socketAddress, 0);
    }
    
    public abstract AsynchronousServerSocketChannel bind(SocketAddress p0, int p1) throws IOException;
    
    @Override
    public abstract <T> AsynchronousServerSocketChannel setOption(SocketOption<T> p0, T p1) throws IOException;
    
    public abstract <A> void accept(A p0, CompletionHandler<AsynchronousSocketChannel, ? super A> p1);
    
    public abstract Future<AsynchronousSocketChannel> accept();
    
    @Override
    public abstract SocketAddress getLocalAddress() throws IOException;
}
